RequestContext class

Request context for interceptors

Constructors

RequestContext({required String endpoint, required String method, Map<String, dynamic>? queryParameters, Map<String, dynamic> data = const {}, Map<String, String>? headers})

Properties

data Map<String, dynamic>
getter/setter pair
endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
getter/setter pair
method String
final
queryParameters Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited