QuickApiInterceptor class abstract
Interceptor interface with error handling
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldAbortOnError → bool
-
Whether to abort request/response if interceptor throws error
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
dynamic error, String endpoint) → Future< void> - Called when an error occurs (optional)
-
onRequest(
RequestContext context) → Future< void> - Called before request is sent
-
onResponse(
ResponseContext context) → Future< void> - Called after successful response
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited